Package: BlockCov
Type: Package
Title: Estimation of Large Block Covariance Matrices
Version: 0.1.1
Author: M. Perrot-Dock\`es, C. Lévy-Leduc
Maintainer: Marie Perrot-Dockès <marie.perrocks@gmail.com>
Description: Computation of large covariance matrices having a block structure up to a permutation of their columns and rows 
    from a small number of samples with respect to the dimension of the matrix.
 The method is described in the paper Perrot-Dockès et al. (2019) <arXiv:1806.10093>.
License: GPL (>= 2)
Encoding: UTF-8
LazyData: true
RoxygenNote: 6.1.1
VignetteBuilder: knitr
Imports: Matrix, stats, Rdpack, BBmisc, dplyr, tibble, magrittr, rlang
Suggests: knitr
RdMacros: Rdpack
NeedsCompilation: no
Packaged: 2019-04-13 18:32:17 UTC; perrot-dockes
Repository: CRAN
Date/Publication: 2019-04-13 22:55:38 UTC
