#' \code{BlockCov} package
#'
#' Estimation of Large Block Covariance Matrices
#'
#' See the README on
#' \href{https://cran.r-project.org/package=BlockCov/vignettes/Vignettes.pdf}{CRAN}
#'\href{https://github.com/Marie-PerrotDockes/BlockCov#readme}{GitHub}
#'
#' @docType package
#' @name BlockCov
NULL
